@@ -1,80 +1,86 @@
-# ===============================================================================
-#
-# PROGRAMMERS:
-#
-# jean-romain.roussel.1@ulaval.ca  -  https://github.com/Jean-Romain/lidR
-#
-# COPYRIGHT:
-#
-# Copyright 2016-2018 Jean-Romain Roussel
-#
-# This file is part of lidR R package.
-#
-# lidR is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>
-#
-# ===============================================================================
+#' An S4 class to represent the header of .las or .laz files
+#'
+#' An S4 class to represent the header of .las or .laz files according to the
+#' \href{https://www.asprs.org/wp-content/uploads/2019/07/LAS_1_4_r15.pdf}{LAS file format specifications}.
+#' A `LASheader` object contains a `list` in the slot `@PHB` with
+#' the data read from the Public Header Block, a `list` in the slot `@VLR` with
+#' the data read from the Variable Length Records and a `list` in the slot `EVLR` with the data read
+#' from the Extended Variable Lenght Records.
+#'
+#' @slot PHB list. Represents the Public Header Block
+#' @slot VLR list. Represents the Variable Length Records
+#' @slot EVLR list. Represents the Extended Variable Length Records
+#'
+#' @exportClass LASheader
+#' @md
+setClass(
+  Class = "LASheader",
+  representation(PHB = "list", VLR = "list", EVLR = "list")
+)
+
+setMethod("initialize", "LASheader", function(.Object, data = list())
+{
+  if (is.data.frame(data))
+  {
+    data <- rlas::header_create(data)
+    if (data[["X scale factor"]] == 1e-8)
+      warning("A scale factor of 1e-8 was infered from the data when creating a LASheader. Data is likely to be over precise", call. = FALSE)
+  }
+
+  stopifnot(is.list(data))
+
+  vlr <- list()
+  if (!is.null(data[["Variable Length Records"]]))
+    vlr <- data[["Variable Length Records"]]
+
+  evlr <- list()
+  if (!is.null(data[["Extended Variable Length Records"]]))
+    evlr <- data[["Extended Variable Length Records"]]
+
+  .Object@PHB <- data
+  .Object@PHB[["Variable Length Records"]] <- NULL
+  .Object@PHB[["Extended Variable Length Records"]] <- NULL
+  .Object@VLR <- vlr
+  .Object@EVLR <- evlr
+
+  return(.Object)
+})
+
 
 #' An S4 class to represent a .las or .laz file
 #'
 #' Class LAS is the representation of a las/laz file according to the
 #' \href{https://www.asprs.org/wp-content/uploads/2019/07/LAS_1_4_r15.pdf}{LAS file format specifications}.
 #'
-#' A \code{LAS} object inherits a \link[sp:Spatial-class]{Spatial} object from \code{sp}. Thus it is
-#' a \code{Spatial} object plus a \code{data.table} with the data read from a \code{las/laz} file and
+#' A `LAS` object contains a `data.table` with the data read from a `las/laz` file and
 #' a \link[=LASheader-class]{LASheader} (see the ASPRS documentation for the
 #' \href{https://www.asprs.org/a/society/committees/standards/LAS_1_4_r13.pdf}{LAS file format}
 #' for more information). Because las files are standardized the table of attributes read from the las/laz file
 #' is also standardized. Columns are named:
 #' \itemize{
-#' \item{\code{X} (numeric)}
-#' \item{\code{Y} (numeric)}
-#' \item{\code{Z} (numeric)}
-#' \item{\code{gpstime} (numeric)}
-#' \item{\code{Intensity} (integer)}
-#' \item{\code{ReturnNumber} (integer)}
-#' \item{\code{NumberOfReturns} (integer)}
-#' \item{\code{ScanDirectionFlag} (integer)}
-#' \item{\code{EdgeOfFlightline} (integer)}
-#' \item{\code{Classification} (integer)}
-#' \item{\code{Synthetic_flag} (logical)}
-#' \item{\code{Keypoint_flag} (logical)}
-#' \item{\code{Withheld_flag} (logical)}
-#' \item{\code{ScanAngleRank} (integer)}
-#' \item{\code{ScanAngle} (numeric)}
-#' \item{\code{UserData} (integer)}
-#' \item{\code{PointSourceID} (integer)}
-#' \item{\code{R,G,B} (integer)}
-#' \item{\code{NIR} (integer)}
+#' \item{`X`, `Y`, `Z` (numeric)}
+#' \item{`gpstime` (numeric)}
+#' \item{`Intensity` (integer)}
+#' \item{`ReturnNumber`, `NumberOfReturns` (integer)}
+#' \item{`ScanDirectionFlag` (integer)}
+#' \item{`EdgeOfFlightline` (integer)}
+#' \item{`Classification` (integer)}
+#' \item{`Synthetic_flag`,`Keypoint_flag`, `Withheld_flag`  (logical)}
+#' \item{`ScanAngleRank`/`ScanAngle`  (integer/numeric)}
+#' \item{`UserData` (integer)}
+#' \item{`PointSourceID` (integer)}
+#' \item{`R`,`G`,`B`, `NIR` (integer)}
 #' }
 #'
-#' @section Extends:
-#' Class  \link[sp:Spatial-class]{Spatial}, directly.
-#'
-#' @slot bbox Object of class \code{matrix}, with bounding box
-#'
-#' @slot proj4string Object of class \link[sp:CRS-class]{CRS}, projection string
-#'
+#' @slot crs Object of class \link[sf:st_crs]{crs} from sf.
 #' @slot data Object of class \link[data.table:data.table]{data.table}. Point cloud data according to the
 #' \href{https://www.asprs.org/wp-content/uploads/2019/07/LAS_1_4_r15.pdf}{LAS file format}
-#'
-#' @slot header Object of class \link[=LASheader-class]{LASheader}. las file header according to the
+#' @slot header Object of class \link[=LASheader-class]{LASheader}. LAS file header according to the
 #' \href{https://www.asprs.org/wp-content/uploads/2019/07/LAS_1_4_r15.pdf}{LAS file format}
-#'
 #' @slot index list. See \link[=lidR-spatial-index]{spatial indexing}.
 #'
-#' @include Class-LASheader.R
 #' @export
+#' @md
 #' @examples
 #' # Read a las/laz file
 #' LASfile <- system.file("extdata", "example.laz", package="rlas")
@@ -102,7 +108,7 @@
 #' data <- data.frame(X = runif(100, 0, 100),
 #'                    Y = runif(100, 0, 100),
 #'                    Z = runif(100, 0, 20))
-#' header <- las@header
+#' header <- header(las)
 #'
 #' # This works but triggers warnings and creates an invalid LAS object
 #' cloud <- LAS(data, header)
@@ -111,8 +117,8 @@
 #' @seealso
 #' \link{readLAS}
 setClass(
-  Class = "LAS", contains = "Spatial",
-  representation(data = "data.table", header = "LASheader", index = "list")
+  Class = "LAS",
+  representation(data = "data.table", header = "LASheader", crs = "crs", index = "list")
 )
 
 setMethod("initialize", "LAS", function(.Object)
@@ -132,8 +138,7 @@ setMethod("initialize", "LAS", function(.Object)
   header$`Y offset` <- 0
   header$`Z offset` <- 0
 
-  .Object@bbox        <- matrix(0, 2, 2)
-  .Object@proj4string <- sp::CRS()
+  .Object@crs         <- sf::NA_crs_
   .Object@header      <- LASheader(header)
   .Object@data        <- data
   .Object@index       <- LIDRDEFAULTINDEX
