@@ -109,12 +109,22 @@
 #' @family metrics
 #' @md
 point_metrics <- function(las, func, k, r,  xyz = FALSE, filter = NULL, ...) {
+
+  if (is_disable_point_metrics())
+    stop("Because of a new CRAN policy that affects numerous packages, we temporarily removed this function to give us time to find a workaround and prevent the package from being removed from CRAN.
+To get a version of the packge with this function enabled please contact us.", call. = FALSE)
+
   UseMethod("point_metrics", las)
 }
 
 #' @export
 point_metrics.LAS <- function(las, func, k, r, xyz = FALSE, filter = NULL, ...) {
 
+  if (is_disable_point_metrics())
+  {
+    C_point_metrics = function(a, b, c, d, e, f) {}
+  }
+
   if (missing(k) && missing(r))  stop("'k' or 'r' is missing", call. = FALSE)
 
   # knn + radius
@@ -279,3 +289,8 @@ point_eigenvalues = function(las, k, r, xyz = FALSE, metrics = FALSE, coeffs = F
   return(M)
 }
 
+is_disable_point_metrics = function()
+{
+  return(!methods::existsFunction("C_point_metrics"))
+}
+
