@@ -1,30 +1,3 @@
-# ===============================================================================
-#
-# PROGRAMMERS:
-#
-# jean-romain.roussel.1@ulaval.ca  -  https://github.com/Jean-Romain/lidR
-#
-# COPYRIGHT:
-#
-# Copyright 2016-2019 Jean-Romain Roussel
-#
-# This file is part of lidR R package.
-#
-# lidR is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>
-#
-# ===============================================================================
-
 #' A set of boolean tests on objects
 #'
 #' \code{is.empty} tests if a \code{LAS} object is a point cloud with 0 points.\cr
@@ -75,7 +48,7 @@ is.empty <- function(las)
 #' @export
 is.overlapping = function(catalog)
 {
-  sfdf          <- sf::st_as_sf(catalog)
+  sfdf          <- catalog@data
   contour       <- sf::st_union(sfdf)
   actual_area   <- sf::st_area(contour)
   average_area  <- actual_area / length(sfdf)
@@ -108,3 +81,9 @@ is.parallelised = function(algorithm)
 
   return(is(algorithm, LIDRALGORITHMOPENMP))
 }
+
+is_raster <- function(raster)
+{
+  raster_is_supported(raster)
+}
+
